==> dl.php?src=linea21_2_0_0.zip: linea21/languages/fr/lang_newsletter.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['newsletter']['name']='newsletter';
$lang['newsletter']['confirm_add'] = "Ajout de la nouvelle newsletter réalisé avec succès\n";
$lang['newsletter']['confirm_mod'] = "Modification de la newsletter réalisée avec succès\n";
$lang['newsletter']['confirm_sup'] ="Suppression de la newsletter réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['newsletter']['add']= 'Ajout d\'une '.$lang['newsletter']['name'];
$lang['newsletter']['mod']= 'Modification d\'une '.$lang['newsletter']['name'];
$lang['newsletter']['sup']= 'Suppression de la '.$lang['newsletter']['name'];
$lang['newsletter']['det']= 'Détail de la '.$lang['newsletter']['name'];
$lang['newsletter']['list']= 'Consultation des newsletters';
$lang['newsletter']['subscribe_title']='Inscription à la newsletter';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['newsletter']['add_title']='Saisie des informations de la nouvelle '.$lang['newsletter']['name'];
$lang['newsletter']['mod_title']='Modification des informations de l\''.$lang['newsletter']['name'];
$lang['newsletter']['recap_commment']='aucun commentaire';


/*	check integrité des données
 *  	*/
$lang['newsletter']['no_title']='Votre newsletter doit impérativement contenir un titre';
$lang['newsletter']['no_body']='Votre newsletter doit impérativement avoir un contenu';
$lang['newsletter']['invalid_mail']= 'L\'email saisi est invalide';
$lang['newsletter']['subscribe_yet']='Vous êtes déjà inscrit à notre newsletter';
$lang['newsletter']['confirm_subscribe']='Vous êtes maintenant inscrit à notre newsletter';
$lang['newsletter']['no_suscribe']='Vous n\'êtes pas inscrit à la newsletter';
$lang['newsletter']['confirm_del']='Votre désinscription a étée réalisée avec succès';
$lang['newsletter']['subscribers_list']='Liste des inscrits à la newsletter';
$lang['newsletter']['email_address']='Adresse email';
$lang['newsletter']['search_address']='Rechercher une adresse';

/*	nommage élément rubrique
 *  	*/
$lang['newsletter']['title']='Titre de la '.$lang['newsletter']['name'];
$lang['newsletter']['body']= 'Contenu';
$lang['newsletter']['auto_populate']= 'Alimenter automatiquement !';
$lang['newsletter']['statut']='Etat de publication';
$lang['newsletter']['author']='auteur';
$lang['newsletter']['nightsend']='envoi dans la nuit suivante';


/*	nommage quickbox
 *  	*/
$lang['newsletter']['qb_titleadd']=' derniers ajouts effectués';
$lang['newsletter']['qb_titlemod']=' dernières modifications effectuées';
$lang['newsletter']['qb_titlesup']=' dernières suppressions effectuées';
$lang['newsletter']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['newsletter']['nb_total']='newsletters sont stockées dans la base de données.';
$lang['newsletter']['statut_filter']='Afficher par statut';
$lang['newsletter']['all']='Afficher la liste complète';
$lang['newsletter']['noresult']='Aucune newsletter ne correspond à ce critère de sélection ';
$lang['newsletter']['content']='Entrez ici votre contenu';
$lang['newsletter']['send_test']='Envoyer un test à %s';
$lang['newsletter']['sending_mail']='Envoi en cours ...';
$lang['newsletter']['sent_successfully']='Newsletter envoyée avec succès!';
$lang['newsletter']['sent_failed']='Erreur lors de l\'envoi.';
$lang['newsletter']['test_add']='test';
$lang['newsletter']['unsubscribe_html']='Pour vous désabonner de notre newsletter, <a href="%s">veuillez cliquer sur ce lien</a>.';
$lang['newsletter']['unsubscribe_txt']='Pour vous désabonner de notre newsletter, veuillez cliquer sur le lien suivant :';

/*	rubrique d'aide
 *  	*/
$lang['newsletter']['help_add1']='Pour ajouter une newsletter, saisissez les informations requises dans le formulaire ci-dessus.';
$lang['newsletter']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['newsletter']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['newsletter']['help_list1']='Pour afficher le détail d\'une newsletter, cliquez sur le titre de celle-ci';
$lang['newsletter']['help_list2']='Vous pouvez supprimer une newsletter en cliquant sur l\'icône de suppression qui lui est associée';
$lang['newsletter']['help_list3']='Vous pouvez modifier une newsletter  en cliquant sur l\'icône de modification qui lui est associée';
$lang['newsletter']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les newsletters desirées';
$lang['newsletter']['help_list5']='Pour ajouter une newsletter, cliquez sur le lien \'ajout d\'une newsletter\' dans la barre de titre';
$lang['newsletter']['help_list6']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['newsletter']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['newsletter']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['newsletter']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['newsletter']['help_det1']='Vous pouvez supprimer cette newsletter en cliquant sur l\'icône de suppression qui lui est associée';
$lang['newsletter']['help_det2']='Vous pouvez modifier cette newsletter en cliquant sur l\'icône de modification qui lui est associée';

$lang['newsletter']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de la newsletter en cours, cliquer sur \'Annuler\'';
?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/fr/lang_newsletter.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['newsletter']['name']='newsletter';
$lang['newsletter']['confirm_add'] = "Ajout de la nouvelle newsletter réalisé avec succès\n";
$lang['newsletter']['confirm_mod'] = "Modification de la newsletter réalisée avec succès\n";
$lang['newsletter']['confirm_sup'] ="Suppression de la newsletter réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['newsletter']['add']= 'Ajout d\'une '.$lang['newsletter']['name'];
$lang['newsletter']['mod']= 'Modification d\'une '.$lang['newsletter']['name'];
$lang['newsletter']['sup']= 'Suppression de la '.$lang['newsletter']['name'];
$lang['newsletter']['det']= 'Détail de la '.$lang['newsletter']['name'];
$lang['newsletter']['list']= 'Consultation des newsletters';
$lang['newsletter']['subscribe_title']='Inscription à la newsletter';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['newsletter']['add_title']='Saisie des informations de la nouvelle '.$lang['newsletter']['name'];
$lang['newsletter']['mod_title']='Modification des informations de l\''.$lang['newsletter']['name'];
$lang['newsletter']['recap_commment']='aucun commentaire';


/*	check integrité des données
 *  	*/
$lang['newsletter']['no_title']='Votre newsletter doit impérativement contenir un titre';
$lang['newsletter']['no_body']='Votre newsletter doit impérativement avoir un contenu';
$lang['newsletter']['invalid_mail']= 'L\'email saisi est invalide';
$lang['newsletter']['subscribe_yet']='Vous êtes déjà inscrit à notre newsletter';
$lang['newsletter']['confirm_subscribe']='Vous êtes maintenant inscrit à notre newsletter';
$lang['newsletter']['no_suscribe']='Vous n\'êtes pas inscrit à la newsletter';
$lang['newsletter']['confirm_del']='Votre désinscription a étée réalisée avec succès';
$lang['newsletter']['subscribers_list']='Liste des inscrits à la newsletter';
$lang['newsletter']['email_address']='Adresse email';
$lang['newsletter']['search_address']='Rechercher une adresse';

/*	nommage élément rubrique
 *  	*/
$lang['newsletter']['title']='Titre de la '.$lang['newsletter']['name'];
$lang['newsletter']['body']= 'Contenu';
$lang['newsletter']['auto_populate']= 'Alimenter automatiquement !';
$lang['newsletter']['statut']='Etat de publication';
$lang['newsletter']['author']='auteur';
$lang['newsletter']['nightsend']='envoi dans la nuit suivante';
$lang['newsletter']['scheduled']='programmé';


/*	nommage quickbox
 *  	*/
$lang['newsletter']['qb_titleadd']=' derniers ajouts effectués';
$lang['newsletter']['qb_titlemod']=' dernières modifications effectuées';
$lang['newsletter']['qb_titlesup']=' dernières suppressions effectuées';
$lang['newsletter']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['newsletter']['nb_total']='newsletters sont stockées dans la base de données.';
$lang['newsletter']['statut_filter']='Afficher par statut';
$lang['newsletter']['all']='Afficher la liste complète';
$lang['newsletter']['noresult']='Aucune newsletter ne correspond à ce critère de sélection ';
$lang['newsletter']['content']='Entrez ici votre contenu';
$lang['newsletter']['send_test']='Envoyer un test à %s';
$lang['newsletter']['send_now']='Envoyer maintenant !';
$lang['newsletter']['send_confirm']='Etes-vous sûr de vouloir envoyer la newsletter maintenant ?';
$lang['newsletter']['sending_mail']='Envoi en cours ... patientez';
$lang['newsletter']['sent_successfully']='Newsletter envoyée avec succès !';
$lang['newsletter']['sent_failed']='Erreur lors de l\'envoi.';
$lang['newsletter']['already_sent']='La newsletter a déjà été envoyée !';
$lang['newsletter']['test_add']='test';
$lang['newsletter']['unsubscribe_html']='Pour vous désabonner de notre newsletter, <a href="%s">veuillez cliquer sur ce lien</a>.';
$lang['newsletter']['unsubscribe_txt']='Pour vous désabonner de notre newsletter, veuillez cliquer sur le lien suivant :';

/*	rubrique d'aide
 *  	*/
$lang['newsletter']['help_add1']='Pour ajouter une newsletter, saisissez les informations requises dans le formulaire ci-dessus.';
$lang['newsletter']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['newsletter']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['newsletter']['help_list1']='Pour afficher le détail d\'une newsletter, cliquez sur le titre de celle-ci';
$lang['newsletter']['help_list2']='Vous pouvez supprimer une newsletter en cliquant sur l\'icône de suppression qui lui est associée';
$lang['newsletter']['help_list3']='Vous pouvez modifier une newsletter  en cliquant sur l\'icône de modification qui lui est associée';
$lang['newsletter']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les newsletters desirées';
$lang['newsletter']['help_list5']='Pour ajouter une newsletter, cliquez sur le lien \'ajout d\'une newsletter\' dans la barre de titre';
$lang['newsletter']['help_list6']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['newsletter']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['newsletter']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['newsletter']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['newsletter']['help_det1']='Vous pouvez supprimer cette newsletter en cliquant sur l\'icône de suppression qui lui est associée';
$lang['newsletter']['help_det2']='Vous pouvez modifier cette newsletter en cliquant sur l\'icône de modification qui lui est associée';

$lang['newsletter']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de la newsletter en cours, cliquer sur \'Annuler\'';
?>
